summaryrefslogtreecommitdiff
path: root/usr/src/uts/common/fs/tmpfs/tmp_dir.c
diff options
context:
space:
mode:
authorbatschul <none@none>2005-09-17 09:54:49 -0700
committerbatschul <none@none>2005-09-17 09:54:49 -0700
commitd5dbd18d69de8954ab5ceb588e99d43fc9b21d46 (patch)
tree2f609bebd6259757c3c5296f372cc6963cd70068 /usr/src/uts/common/fs/tmpfs/tmp_dir.c
parent264d6c47155e48a72de1c618998b22b3057c0de1 (diff)
downloadillumos-joyent-d5dbd18d69de8954ab5ceb588e99d43fc9b21d46.tar.gz
PSARC 2005/287 obsolete and remove vn_vfslock interface
6265230 retire usage of deprecated vn_vfslock() interface from ON
Diffstat (limited to 'usr/src/uts/common/fs/tmpfs/tmp_dir.c')
-rw-r--r--usr/src/uts/common/fs/tmpfs/tmp_dir.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/usr/src/uts/common/fs/tmpfs/tmp_dir.c b/usr/src/uts/common/fs/tmpfs/tmp_dir.c
index 75d67bcd33..de405078c3 100644
--- a/usr/src/uts/common/fs/tmpfs/tmp_dir.c
+++ b/usr/src/uts/common/fs/tmpfs/tmp_dir.c
@@ -20,7 +20,7 @@
* CDDL HEADER END
*/
/*
- * Copyright 2004 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2005 Sun Microsystems, Inc. All rights reserved.
* Use is subject to license terms.
*/
@@ -782,10 +782,10 @@ tdirrename(
goto out;
}
/*
* vn_vfslock will prevent mounts from using the directory
* until we are done.
*/
- if (vn_vfslock(TNTOV(to))) {
+ if (vn_vfswlock(TNTOV(to))) {
error = EBUSY;
goto out;
}
@@ -782,10 +782,10 @@ tdirrename(
}
/*
- * vn_vfslock will prevent mounts from using the directory
+ * vn_vfswlock will prevent mounts from using the directory
* until we are done.
*/